==> zio-aws-elasticloadbalancing_2.13-5.17.122.1-sources.jar: zio/aws/elasticloadbalancing/model/DescribeAccountLimitsRequest.scala <==
package zio.aws.elasticloadbalancing.model
import java.lang.Integer
import zio.ZIO
import zio.aws.elasticloadbalancing.model.primitives.{PageSize, Marker}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeAccountLimitsRequest(
    marker: Option[Marker] = None,
    pageSize: Option[PageSize] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest = {
    import DescribeAccountLimitsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
      .builder()
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(pageSize.map(value => PageSize.unwrap(value): Integer))(
        _.pageSize
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly =
    zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest
      .wrap(buildAwsValue())
}
object DescribeAccountLimitsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest =
      zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest(
        marker.map(value => value),
        pageSize.map(value => value)
      )
    def marker: Option[Marker]
    def pageSize: Option[PageSize]
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
    def getPageSize: ZIO[Any, AwsError, PageSize] =
      AwsError.unwrapOptionField("pageSize", pageSize)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ) extends zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly {
    override val marker: Option[Marker] = scala
      .Option(impl.marker())
      .map(value => zio.aws.elasticloadbalancing.model.primitives.Marker(value))
    override val pageSize: Option[PageSize] = scala
      .Option(impl.pageSize())
      .map(value =>
        zio.aws.elasticloadbalancing.model.primitives.PageSize(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ): zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticloadbalancing_2.13-5.17.162.2-sources.jar: zio/aws/elasticloadbalancing/model/DescribeAccountLimitsRequest.scala <==
package zio.aws.elasticloadbalancing.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.elasticloadbalancing.model.primitives.{PageSize, Marker}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeAccountLimitsRequest(
    marker: Optional[Marker] = Optional.Absent,
    pageSize: Optional[PageSize] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest = {
    import DescribeAccountLimitsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
      .builder()
      .optionallyWith(
        marker.map(value => Marker.unwrap(value): java.lang.String)
      )(_.marker)
      .optionallyWith(pageSize.map(value => PageSize.unwrap(value): Integer))(
        _.pageSize
      )
      .build()
  }
  def asReadOnly
      : zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly =
    zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest
      .wrap(buildAwsValue())
}
object DescribeAccountLimitsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest =
      zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest(
        marker.map(value => value),
        pageSize.map(value => value)
      )
    def marker: Optional[Marker]
    def pageSize: Optional[PageSize]
    def getMarker: ZIO[Any, AwsError, Marker] =
      AwsError.unwrapOptionField("marker", marker)
    def getPageSize: ZIO[Any, AwsError, PageSize] =
      AwsError.unwrapOptionField("pageSize", pageSize)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ) extends zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly {
    override val marker: Optional[Marker] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => zio.aws.elasticloadbalancing.model.primitives.Marker(value))
    override val pageSize: Optional[PageSize] = zio.aws.core.internal
      .optionalFromNullable(impl.pageSize())
      .map(value =>
        zio.aws.elasticloadbalancing.model.primitives.PageSize(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancing.model.DescribeAccountLimitsRequest
  ): zio.aws.elasticloadbalancing.model.DescribeAccountLimitsRequest.ReadOnly =
    new Wrapper(impl)
}
